@@ -1,6 +1,10 @@
 # -*- coding: utf-8 -*-
 
-"""Top-level module for Countdoom."""
+"""
+Top-level module for Countdoom.
+
+SPDX-License-Identifier: MIT
+"""
 
 from countdoom import cli  # pylint: disable=C0415
 
